@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Any::Moose;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 use File::Temp;
@@ -49,6 +49,10 @@ sub BUILD {
         $self->conf->{port} = '0';
     }
 
+    unless (defined $self->conf->{dir}) {
+        $self->conf->{dir} = "$tmpdir/";
+    }
+
     if ($self->conf->{loglevel} and $self->conf->{loglevel} eq 'warning') {
         warn "Test::RedisServer does not support \"loglevel warning\", using \"notice\" instead.\n";
         $self->conf->{loglevel} = 'notice';
